==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FunnelSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { FunnelSliceDataContextDescription } from "./FunnelSliceDataContextDescription";
/**
 * @hidden
 */
var FunnelSliceDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunnelSliceDataContextDescriptionMetadata, _super);
    function FunnelSliceDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelSliceDataContextDescriptionMetadata.b = function (a) {
        if (FunnelSliceDataContextDescriptionMetadata.a == null) {
            FunnelSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelSliceDataContextDescriptionMetadata.c(FunnelSliceDataContextDescriptionMetadata.a);
        }
        if (a.j(FunnelSliceDataContextDescriptionMetadata.a)) {
            return;
        }
        a.y(FunnelSliceDataContextDescriptionMetadata.a);
    };
    FunnelSliceDataContextDescriptionMetadata.c = function (a) {
        DataContextDescriptionMetadata.c(a);
        a.item("ItemOutline", "Brush");
    };
    FunnelSliceDataContextDescriptionMetadata.d = function (a) {
        FunnelSliceDataContextDescriptionMetadata.b(a);
        a.aa("FunnelSliceDataContext", function () { return new FunnelSliceDataContextDescription(); });
        a.z("FunnelSliceDataContext", FunnelSliceDataContextDescriptionMetadata.a);
    };
    FunnelSliceDataContextDescriptionMetadata.$t = markType(FunnelSliceDataContextDescriptionMetadata, 'FunnelSliceDataContextDescriptionMetadata');
    FunnelSliceDataContextDescriptionMetadata.a = null;
    return FunnelSliceDataContextDescriptionMetadata;
}(Base));
export { FunnelSliceDataContextDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/FunnelSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { FunnelSliceDataContextDescription } from "./FunnelSliceDataContextDescription";
/**
 * @hidden
 */
var FunnelSliceDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunnelSliceDataContextDescriptionMetadata, _super);
    function FunnelSliceDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelSliceDataContextDescriptionMetadata.b = function (a) {
        if (FunnelSliceDataContextDescriptionMetadata.a == null) {
            FunnelSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelSliceDataContextDescriptionMetadata.c(FunnelSliceDataContextDescriptionMetadata.a);
        }
        if (a.k(FunnelSliceDataContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(FunnelSliceDataContextDescriptionMetadata.a);
    };
    FunnelSliceDataContextDescriptionMetadata.c = function (a) {
        DataContextDescriptionMetadata.c(a);
        a.item("ItemOutline", "Brush");
    };
    FunnelSliceDataContextDescriptionMetadata.d = function (a) {
        FunnelSliceDataContextDescriptionMetadata.b(a);
        a.ac("FunnelSliceDataContext", function () { return new FunnelSliceDataContextDescription(); });
        a.ab("FunnelSliceDataContext", FunnelSliceDataContextDescriptionMetadata.a);
    };
    FunnelSliceDataContextDescriptionMetadata.$t = markType(FunnelSliceDataContextDescriptionMetadata, 'FunnelSliceDataContextDescriptionMetadata');
    FunnelSliceDataContextDescriptionMetadata.a = null;
    return FunnelSliceDataContextDescriptionMetadata;
}(Base));
export { FunnelSliceDataContextDescriptionMetadata };
